@@ -1,36 +1,33 @@
 package Config::JFDI::Source::Loader;
 
-use Moose;
-use MooseX::AttributeHelpers;
+use Any::Moose;
 
 use Config::Any;
 use Carp;
-use List::MoreUtils qw/any/;
+use List::MoreUtils qw/ any /;
 
-has name => qw/is ro required 0 isa Str|ScalarRef/;
+has name => qw/ is ro required 0 isa Str|ScalarRef /;
 
-has path => qw/is ro default ./;
+has path => qw/ is ro default . /;
 
-has driver => qw/is ro lazy_build 1/;
+has driver => qw/ is ro lazy_build 1 /;
 sub _build_driver {
     return {};
 }
 
-has local_suffix => qw/is ro required 1 lazy 1 default local/;
+has local_suffix => qw/ is ro required 1 lazy 1 default local /;
 
-has no_env => qw/is ro required 1/, default => 0;
+has no_env => qw/ is ro required 1 /, default => 0;
 
-has no_local => qw/is ro required 1/, default => 0;
+has no_local => qw/ is ro required 1 /, default => 0;
 
-has env_lookup => qw/is ro/, default => sub { [] };
+has env_lookup => qw/ is ro /, default => sub { [] };
 
-has path_is_file => qw/is ro default 0/;
+has path_is_file => qw/ is ro default 0 /;
 
-has _found => qw/metaclass Collection::Array is rw isa ArrayRef/, provides => {qw/
-    elements found
-/};
+has _found => qw/ is rw isa ArrayRef /;
 
-sub _env(@) {
+sub _env (@) {
     my $key = uc join "_", @_;
     $key =~ s/::/_/g;
     $key =~ s/\W/_/g;
@@ -86,6 +83,12 @@ sub read {
     return $self->no_local ? @cfg : (@cfg, @local_cfg);
 }
 
+sub found {
+    my $self = shift;
+    die if @_;
+    return @{ $self->_found };
+}
+
 around found => sub {
     my $inner = shift;
     my $self = shift;
@@ -172,6 +175,13 @@ sub _get_extensions {
     return @{ Config::Any->extensions }
 }
 
+sub file_extension ($) {
+    my $path = shift;
+    return if -d $path; 
+    my ($extension) = $path =~ m{\.([^/\.]{1,4})$};
+    return $extension;
+}
+
 sub _get_path {
     my $self = shift;
 
@@ -181,8 +191,7 @@ sub _get_path {
     $path = $self->_env_lookup('CONFIG') unless $self->no_env;
     $path ||= $self->path;
 
-    # TODO Uhh, what if path is -d? 
-    my ($extension) = ($path =~ m{\.(.{1,4})$});
+    my $extension = file_extension $path;
 
     if (-d $path) {
         $path =~ s{[\/\\]$}{}; # Remove any trailing slash, e.g. apple/ or apple\ => apple
